@@ -49,7 +49,11 @@ class PdpRepo:
             policyDicts = policiesDict["Responses"][self.__policiesTableName]
             return [
                 ObjectUtil.fromDict(
-                    dictValue = policyDict,
+                    dictValue = {
+                        **policyDict, 
+                        "entityUri": policyDict[self.__policiesTableEntityUriFieldName], 
+                        "policyType": policyDict[self.__policiesTablePolicyTypeFieldName]
+                    },
                     objectType = Policy
                 ) for policyDict in policyDicts
             ]
